@@ -379,8 +379,8 @@ static VAStatus gen7_vme_avc_state_setup(VADriverContextP ctx,
     vme_state_message = (unsigned int *)vme_context->vme_state.bo->virtual;
 
     if (((slice_param->slice_type == SLICE_TYPE_P) ||
-        (slice_param->slice_type == SLICE_TYPE_SP) &&
-        !is_low_quality)) {
+         (slice_param->slice_type == SLICE_TYPE_SP)) &&
+        !is_low_quality) {
         vme_state_message[0] = 0x01010101;
         vme_state_message[1] = 0x10010101;
         vme_state_message[2] = 0x0F0F0F0F;
@@ -615,7 +615,7 @@ static void gen7_vme_pipeline_programing(VADriverContextP ctx,
     }
 
     if ((pSliceParameter->slice_type == SLICE_TYPE_I) ||
-	(pSliceParameter->slice_type == SLICE_TYPE_I)) {
+	(pSliceParameter->slice_type == SLICE_TYPE_SI)) {
 	kernel_shader = AVC_VME_INTRA_SHADER;
     } else if ((pSliceParameter->slice_type == SLICE_TYPE_P) ||
                (pSliceParameter->slice_type == SLICE_TYPE_SP)) {
@@ -1031,6 +1031,7 @@ Bool gen7_vme_context_init(VADriverContextP ctx, struct intel_encoder_context *e
     struct gen6_vme_context *vme_context = calloc(1, sizeof(struct gen6_vme_context));
     struct i965_kernel *vme_kernel_list = NULL;
 
+    assert(vme_context);
     vme_context->gpe_context.surface_state_binding_table.length =
         (SURFACE_STATE_PADDED_SIZE + sizeof(unsigned int)) * MAX_MEDIA_SURFACES_GEN6;
 
