@@ -330,6 +330,9 @@
 #define GEN7_3DSTATE_VF                                 CMD(3, 0, 0x0c)
 #define GEN8_3DSTATE_VF_INSTANCING                      CMD(3, 0, 0x49)
 
+#define GEN7_3DSTATE_VF                                 CMD(3, 0, 0x0c)
+#define GEN8_3DSTATE_VF_INSTANCING                      CMD(3, 0, 0x49)
+
 #define MFX(pipeline, op, sub_opa, sub_opb)     \
     (3 << 29 |                                  \
      (pipeline) << 27 |                         \
@@ -396,6 +399,11 @@
 
 #define MFD_VP8_BSD_OBJECT                      MFX(2, 4, 1, 8)
 
+#define MFX_VP8_ENCODER_CFG                     MFX(2, 4, 2, 1)
+
+#define MFX_VP8_BSP_BUF_BASE_ADDR_STATE         MFX(2, 4, 2, 3)
+
+#define MFX_VP8_PAK_OBJECT                      MFX(2, 4, 2, 9)
 
 #define VEB(pipeline, op, sub_opa, sub_opb)     \
      (3 << 29 |                                 \
@@ -429,6 +437,9 @@
 #define HCP_PAK_OBJECT                          HCP(0x21)
 #define HCP_INSERT_PAK_OBJECT                   HCP(0x22)
 
+#define HCP_VP9_SEGMENT_STATE                   HCP(0x32)
+#define HCP_VP9_PIC_STATE                       HCP(0x30)
+
 #define I965_DEPTHFORMAT_D32_FLOAT              1
 
 #define BASE_ADDRESS_MODIFY             (1 << 0)
@@ -743,6 +754,8 @@
 #define _3DPRIM_LINESTRIP_CONT_BF 0x14
 #define _3DPRIM_TRIFAN_NOSTIPPLE  0x15
 
+#define GEN8_3DSTATE_VF_INSTANCING	CMD(3, 0, 0x49)
+#define GEN8_3DSTATE_VF_SGVS		CMD(3, 0, 0x4a)
 #define GEN8_3DSTATE_VF_TOPOLOGY	CMD(3, 0, 0x4b)
 
 #define I965_TILEWALK_XMAJOR                 0
@@ -787,6 +800,8 @@
 #define SURFACE_FORMAT_R8B8_UNORM       10
 #define SURFACE_FORMAT_R8_UNORM         11
 #define SURFACE_FORMAT_Y8_UNORM         12
+#define SURFACE_FORMAT_P010             13
+#define SURFACE_FORMAT_P016             14
 
 #define AVS_FILTER_ADAPTIVE_8_TAP       0
 #define AVS_FILTER_NEAREST              1
@@ -894,6 +909,12 @@
 
 #define HCP_CODEC_HEVC                          0
 
+#define HCP_CODEC_VP9                           1
+#define HCP_VP9_KEY_FRAME                       0
+#define HCP_VP9_INTER_FRAME                     1
+#define HCP_VP9_PROFILE0                        0     /* 8 bit 420 only */
+#define HCP_VP9_PROFILE2                        2     /* 10 bits 420 only */
+
 #define HCP_CODEC_SELECT_DECODE                 0
 #define HCP_CODEC_SELECT_ENCODE                 1
 
