@@ -135,16 +135,53 @@ CHIPSET(0x22B2, chv, chv,       "Intel(R) CherryView")
 CHIPSET(0x22B3, chv, chv,       "Intel(R) CherryView")
 CHIPSET(0x1902, skl, skl,       "Intel(R) Skylake")
 CHIPSET(0x1906, skl, skl,       "Intel(R) Skylake")
+CHIPSET(0x190A, skl, skl,       "Intel(R) Skylake")
+CHIPSET(0x190B, skl, skl,       "Intel(R) Skylake")
 CHIPSET(0x190E, skl, skl,       "Intel(R) Skylake")
 CHIPSET(0x1912, skl, skl,       "Intel(R) Skylake")
 CHIPSET(0x1913, skl, skl,       "Intel(R) Skylake")
 CHIPSET(0x1915, skl, skl,       "Intel(R) Skylake")
 CHIPSET(0x1916, skl, skl,       "Intel(R) Skylake")
 CHIPSET(0x1917, skl, skl,       "Intel(R) Skylake")
+CHIPSET(0x191A, skl, skl,       "Intel(R) Skylake")
 CHIPSET(0x191B, skl, skl,       "Intel(R) Skylake")
+CHIPSET(0x191D, skl, skl,       "Intel(R) Skylake")
 CHIPSET(0x191E, skl, skl,       "Intel(R) Skylake")
 CHIPSET(0x1921, skl, skl,       "Intel(R) Skylake")
+CHIPSET(0x1923, skl, skl,       "Intel(R) Skylake")
 CHIPSET(0x1926, skl, skl,       "Intel(R) Skylake")
+CHIPSET(0x1927, skl, skl,       "Intel(R) Skylake")
+CHIPSET(0x192A, skl, skl,       "Intel(R) Skylake")
 CHIPSET(0x192B, skl, skl,       "Intel(R) Skylake")
+CHIPSET(0x192D, skl, skl,       "Intel(R) Skylake")
+CHIPSET(0x1932, skl, skl,       "Intel(R) Skylake")
 CHIPSET(0x193A, skl, skl,       "Intel(R) Skylake")
 CHIPSET(0x193B, skl, skl,       "Intel(R) Skylake")
+CHIPSET(0x193D, skl, skl,       "Intel(R) Skylake")
+CHIPSET(0x0A84, bxt, bxt,       "Intel(R) Broxton")
+CHIPSET(0x1A84, bxt, bxt,       "Intel(R) Broxton")
+CHIPSET(0x1A85, bxt, bxt,       "Intel(R) Broxton")
+CHIPSET(0x5A84, bxt, bxt,       "Intel(R) Broxton")
+CHIPSET(0x5A85, bxt, bxt,       "Intel(R) Broxton")
+CHIPSET(0x5916, kbl, kbl,       "Intel(R) Kabylake")
+CHIPSET(0x5913, kbl, kbl,       "Intel(R) Kabylake")
+CHIPSET(0x5906, kbl, kbl,       "Intel(R) Kabylake")
+CHIPSET(0x5926, kbl, kbl,       "Intel(R) Kabylake")
+CHIPSET(0x5921, kbl, kbl,       "Intel(R) Kabylake")
+CHIPSET(0x5915, kbl, kbl,       "Intel(R) Kabylake")
+CHIPSET(0x590E, kbl, kbl,       "Intel(R) Kabylake")
+CHIPSET(0x591E, kbl, kbl,       "Intel(R) Kabylake")
+CHIPSET(0x5912, kbl, kbl,       "Intel(R) Kabylake")
+CHIPSET(0x5917, kbl, kbl,       "Intel(R) Kabylake")
+CHIPSET(0x5902, kbl, kbl,       "Intel(R) Kabylake")
+CHIPSET(0x5932, kbl, kbl,       "Intel(R) Kabylake")
+CHIPSET(0x591B, kbl, kbl,       "Intel(R) Kabylake")
+CHIPSET(0x592B, kbl, kbl,       "Intel(R) Kabylake")
+CHIPSET(0x593B, kbl, kbl,       "Intel(R) Kabylake")
+CHIPSET(0x590B, kbl, kbl,       "Intel(R) Kabylake")
+CHIPSET(0x591A, kbl, kbl,       "Intel(R) Kabylake")
+CHIPSET(0x592A, kbl, kbl,       "Intel(R) Kabylake")
+CHIPSET(0x593A, kbl, kbl,       "Intel(R) Kabylake")
+CHIPSET(0x590A, kbl, kbl,       "Intel(R) Kabylake")
+CHIPSET(0x591D, kbl, kbl,       "Intel(R) Kabylake")
+CHIPSET(0x593D, kbl, kbl,       "Intel(R) Kabylake")
\ No newline at end of file
