@@ -80,6 +80,7 @@ struct intel_batchbuffer;
 extern uint32_t g_intel_debug_option_flags;
 #define VA_INTEL_DEBUG_OPTION_ASSERT    (1 << 0)
 #define VA_INTEL_DEBUG_OPTION_BENCH     (1 << 1)
+#define VA_INTEL_DEBUG_OPTION_DUMP_AUB  (1 << 2)
 
 #define ASSERT_RET(value, fail_ret) do {    \
         if (!(value)) {                     \
@@ -118,7 +119,7 @@ extern uint32_t g_intel_debug_option_flags;
         static int g_once = 1;                  \
         if (g_once) {                           \
             g_once = 0;                         \
-            printf("WARNING: " __VA_ARGS__);    \
+            fprintf(stderr, "WARNING: " __VA_ARGS__);    \
         }                                       \
     } while (0)
 
@@ -135,6 +136,8 @@ struct intel_device_info
     unsigned int is_baytrail    : 1; /* gen7 */
     unsigned int is_haswell     : 1; /* gen7 */
     unsigned int is_cherryview  : 1; /* gen8 */
+    unsigned int is_broxton     : 1; /* gen9 */
+    unsigned int is_kabylake    : 1; /* gen9p5 */
 };
 
 struct intel_driver_data 
@@ -196,4 +199,6 @@ struct intel_region
 
 #define IS_GEN9(device_info)            (device_info->gen == 9)
 
+#define IS_KBL(device_info)             (device_info->is_kabylake)
+
 #endif /* _INTEL_DRIVER_H_ */
